import { AsyncValidatorFn, ValidatorFn } from '@angular/forms';
import { MimeType } from './mime-types';
/**
 * @description
 * Validator that requires the maximum length of files that can be uploaded.
 *
 * @example
 * Validate that the user selected maximum 3 files:
 *
 * ```
 * const fileUpload = new FormControl(null, maxFilesValidator(3));
 * console.log(fileUpload.errors); // { maxFiles: 3 }
 * ```
 *
 * @param {MimeType[]} maxFiles - The maximum number of files allowed.
 * @returns A validator function that returns an error map with the
 * `maxFiles` if the validation check fails, otherwise `null`.
 */
export declare const maxFilesValidator: (maxFiles: number) => ValidatorFn;
/**
 * @description
 * Validator that requires the maximum size (in bytes) of files that can be uploaded.
 *
 * @example
 * Validate that the user doesn't select a file have a size up to 300Kb:
 *
 * ```
 * const fileUpload = new FormControl(null, maxSizeValidator(300000));
 * console.log(fileUpload.errors); // { maxSize: 300000 }
 * ```
 *
 * @param {MimeType[]} maxFileSize - The maximum filesize allowed.
 * @returns A validator function that returns an error map with the
 * `maxSize` if the validation check fails, otherwise `null`.
 */
export declare const maxSizeValidator: (maxSize: number) => ValidatorFn;
/**
 * @description
 * Validator that requires the maximum size (in bytes) per file that can be uploaded.
 *
 * @example
 * Validates that the user doesn't select a file that exceeds the provided size
 *
 * @param {MimeType[]} maxFileSize - The maximum filesize allowed.
 * @returns A validator function that returns an error map with the
 * `maxFileSize` and the `indexes` of the file/files that exceeded the max size if the validation check fails, otherwise `null`.
 */
export declare const maxFileSizeValidator: (maxFileSize: number) => ValidatorFn;
/**
 * @description
 * Validator that requires an array of mime type that can be uploaded.
 *
 * @example
 * Validate that the user doesn't select a file having another extension than .jpg or .jpeg:
 * ```
 * const fileUpload = new FormControl(null, mimeTypeExtensionValidator(['image/jpeg'])),
 * console.log(fileUpload.errors); // { invalidFileExtension: ['image/jpeg'] }
 * ```
 *
 * @param {MimeType[]} mimeTypes - The list of allowed MIME types.
 * @returns A validator function that returns an error map with the
 * `invalidFileExtension` if the validation check fails, otherwise `null`.
 */
export declare const mimeTypeExtensionValidator: (mimeTypes: string[]) => ValidatorFn;
/**
 * @description
 * Validator that requires an array of mime type that can be uploaded.
 *
 * @example
 * Validate that the user doesn't select a file having another extension than .jpg or .jpeg:
 *
 * ```
 * const fileUpload = new FormControl(null, mimeTypeExtensionValidator(['image/jpeg'])),
 * console.log(fileUpload.errors); // { invalidMimeFileType: ['image/jpeg'] }
 * ```
 * @param {MimeType[]} mimeTypes - The list of allowed MIME types.
 * @returns An Async validator function that returns an error map with the
 * `invalidMimeFileType` if the validation check fails, otherwise `null`.
 */
export declare const asyncMimeTypeExtensionValidator: (mimeTypes: MimeType[]) => AsyncValidatorFn;
//# sourceMappingURL=eui-file-upload.validators.d.ts.map