import { ValidatorFn } from '@angular/forms';
/**
 * @description
 * Validator that requires the length of the editor's content, out of HTML tags or JSON structure, to be greater than or equal
 * to the provided minimum length.
 *
 * @usageNotes
 * Validate that the editor has a minimum of 5 characters:
 *
 * ```typescript
 * const editor = new FormControl('ng', euiEditorMinLength(5));
 * console.log(editor.errors); // { minlength: { minLength: 5, actual: 2 } }
 * ```
 *
 * @returns A validator function that returns an error map with the
 * `minlength` if the validation check fails, otherwise `null`.
 */
export declare const euiEditorMinLength: (minLength: number) => ValidatorFn;
/**
 * @description
 * Validator that requires the length of the editor's content, out of HTML tags or JSON structure, to be less than or equal
 * to the provided maximum length.
 *
 * @usageNotes
 * Validate that the editor has a maximum of 10 characters:
 *
 * ```typescript
 * const editor = new FormControl('ng angular reactive', euiEditorMaxLength(10));
 * console.log(editor.errors); // { maxLength: { maxLength: 10, actual: 19 } }
 * ```
 *
 * @returns A validator function that returns an error map with the
 * `maxlength` if the validation check fails, otherwise `null`.
 */
export declare const euiEditorMaxLength: (maxLength: number) => ValidatorFn;
/**
 * @description
 * Validator that requires the number of words in the editor, out of HTML tags or JSON structure, to be greater than or equal
 * to the provided minimum number.
 *
 * @usageNotes
 * Validate that the editor has a minimum of 5 words:
 *
 * ```typescript
 * const editor = new FormControl('ng angular', euiEditorMinWords(5));
 * console.log(editor.errors); // { minWords: { minWords: 5, actual: 2 } }
 * ```
 *
 * @returns A validator function that returns an error map with the
 * `minWords` if the validation check fails, otherwise `null`.
 */
export declare const euiEditorMinWords: (minWords: number) => ValidatorFn;
/**
 * @description
 * Validator that requires the number of words in the editor, out of HTML tags or JSON structure, to be less than or equal
 * to the provided maximum number.
 *
 * @usageNotes
 * Validate that the editor has a maximum of 10 words:
 *
 * ```typescript
 * const editor = new FormControl('ng angular reactive forms editor wysiwyg eui ec europa npm node', euiEditorMaxWords(10));
 * console.log(editor.errors); // { maxWords: { maxWords: 10, actual: 11 } }
 * ```
 *
 * @returns A validator function that returns an error map with the
 * `maxWords` if the validation check fails, otherwise `null`.
 */
export declare const euiEditorMaxWords: (maxWords: number) => ValidatorFn;
/**
 * @description
 * Validator that requires the number of bytes in the editor, with HTML tags or JSON structure, to be greater than or equal
 * to the provided minimum number.
 *
 * @usageNotes
 * Validate that the editor has a minimum of 20 bytes:
 *
 * ```typescript
 * const editor = new FormControl('<p>europa.eu</p>', euiEditorMinBytes(20));
 * console.log(editor.errors); // { minBytes: { minBytes: 20, actual: 16 } }
 * ```
 *
 * @returns A validator function that returns an error map with the
 * `minBytes` if the validation check fails, otherwise `null`.
 */
export declare const euiEditorMinBytes: (minBytes: number) => ValidatorFn;
/**
 * @description
 * Validator that requires the number of bytes in the editor, with HTML tags or JSON structure, to be less than or equal
 * to the provided minimum number.
 *
 * @usageNotes
 * Validate that the editor has a maximum of 20 bytes:
 *
 * ```typescript
 * const editor = new FormControl('<p>europa.eu site</p>', euiEditorMinBytes(20));
 * console.log(editor.errors); // { maxBytes: { maxBytes: 20, actual: 21 } }
 * ```
 *
 * @returns A validator function that returns an error map with the
 * `maxBytes` if the validation check fails, otherwise `null`.
 */
export declare const euiEditorMaxBytes: (maxBytes: number) => ValidatorFn;
//# sourceMappingURL=eui-editor.validators.d.ts.map