import * as i0 from '@angular/core';
import { EventEmitter, inject, ElementRef, booleanAttribute, ViewChild, forwardRef, ContentChildren, Output, Input, HostBinding, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import * as i1 from '@eui/components/shared';
import { BaseStatesDirective } from '@eui/components/shared';
import { EuiIconSvgComponent, EUI_ICON } from '@eui/components/eui-icon';
import * as i2 from '@eui/components/eui-icon-button';
import { EUI_ICON_BUTTON } from '@eui/components/eui-icon-button';

/**
 * @description
 * Chips are compact elements that allow users to enter information, select a choice, filter content or trigger an action.
 * The eui-chip component can also be displayed dynamically as a group of multiple interactive elements, see eui-chip-list.
 */
class EuiChipComponent {
    constructor() {
        /**
         * Sets the `role` attribute for the host element.
         *
         * @default 'status'
         */
        this.role = 'status';
        /**
         * Sets the `aria-label` attribute for the host element.
         *
         * @default 'Chip content'
         */
        this.ariaLabel = 'Chip content';
        /**
         * Sets the `data-e2e` attribute for the host element.
         *
         * @default 'eui-chip'
         */
        this.e2eAttr = 'eui-chip';
        /**
         * Sets the euiInternalId of the chip.
         *
         * @default null
         */
        this.euiInternalId = null;
        /**
         * Sets the data of the chip like tooltip configuration.
         */
        // TODO: type should be specific
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.data = {
            id: crypto.randomUUID(),
            tooltip: {
                color: 'euiTooltipPrimary',
                contentAlignment: null,
                position: 'above',
            },
        };
        /**
         * Wether the chip can be removed.
         *
         * @default false
         */
        this.isChipRemovable = false;
        /**
         * @deprecated This option is not applicable anymore to comply design System.
         */
        this.isSquared = false;
        /**
         * Wether the chip is filled with color.
         *
         * @default false
         */
        this.isFilled = false;
        /**
         * Event emitted when the chip is removed.
         */
        this.remove = new EventEmitter();
        this.baseStatesDirective = inject(BaseStatesDirective);
        this._elementRef = inject(ElementRef);
    }
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses() {
        return [
            this.baseStatesDirective.getCssClasses('eui-chip'),
            this.isChipRemovable ? 'eui-chip--removable' : '',
            this.isFilled ? 'eui-chip--filled' : '',
        ].join(' ').trim();
    }
    ngAfterContentInit() {
        if (!this.data.id && this.id) {
            this.data = Object.assign(this.data, { id: this.id });
        }
        if (this._elementRef.nativeElement.parentElement?.classList.contains('eui-chip-list__chip-container')) {
            this.role = 'listitem';
        }
    }
    /**
     * Remove chip handler
     *
     * @param event Click event
     */
    onRemove(event) {
        if (event instanceof KeyboardEvent && event.code === 'Backspace') {
            this.remove.emit({ chip: this.data, event });
        }
        else {
            this.remove.emit(this.data);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiChipComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiChipComponent, isStandalone: true, selector: "eui-chip, span[euiChip], li[euiChip]", inputs: { ariaLabel: "ariaLabel", e2eAttr: "e2eAttr", euiInternalId: "euiInternalId", tooltipMessage: "tooltipMessage", id: "id", data: "data", isChipRemovable: ["isChipRemovable", "isChipRemovable", booleanAttribute], isSquared: ["isSquared", "isSquared", booleanAttribute], isFilled: ["isFilled", "isFilled", booleanAttribute] }, outputs: { remove: "remove" }, host: { properties: { "class": "this.cssClasses", "attr.role": "this.role", "attr.aria-label": "this.ariaLabel", "attr.data-e2e": "this.e2eAttr" } }, queries: [{ propertyName: "euiIcons", predicate: i0.forwardRef(() => EuiIconSvgComponent) }], viewQueries: [{ propertyName: "chipLabel", first: true, predicate: ["chipLabel"], descendants: true }], hostDirectives: [{ directive: i1.BaseStatesDirective, inputs: ["euiPrimary", "euiPrimary", "euiSecondary", "euiSecondary", "euiSuccess", "euiSuccess", "euiInfo", "euiInfo", "euiWarning", "euiWarning", "euiDanger", "euiDanger", "euiAccent", "euiAccent", "euiVariant", "euiVariant", "euiSizeS", "euiSizeS", "euiOutline", "euiOutline", "euiDisabled", "euiDisabled"] }], ngImport: i0, template: "<div class=\"eui-chip-wrapper\">\n    <div class=\"eui-chip__content-container\" #chipLabel>\n        <ng-content></ng-content>\n    </div>\n    @if (isChipRemovable) {\n        <eui-icon-button\n            class=\"eui-chip__close\"\n            ariaLabel=\"Remove {{ chipLabel.textContent }} chip\"\n            icon=\"close:outline\"\n            euiRounded\n            hasNoPadding\n            [euiVariant]=\"baseStatesDirective.euiVariant\"\n            (keydown.enter)=\"onRemove($event)\"\n            (keydown.backspace)=\"onRemove($event)\"\n            (buttonClick)=\"onRemove($event)\">\n        </eui-icon-button>\n    }\n</div>\n", styles: [".eui-19.eui-t-ds2025 :host.eui-chip{--_size-s-font: var(--eui-f-body-s-regular);--_size-m-font: var(--eui-f-body-m-regular)}.eui-19 :host.eui-chip{--_bg-color: var(--eui-c-s-secondary-surface-light);--_color: var(--eui-c-s-secondary-on-surface-light);--_close-hover-color: var(--eui-c-s-secondary-surface-light-hover);--_border-outline-color: var(--eui-c-s-secondary-border);--_border-color: var(--eui-c-s-secondary-border-light);--_size-s-font: var(--eui-f-s);--_size-m-font: var(--eui-f-m)}.eui-19 :host.eui-chip--primary{--_bg-color: var(--eui-c-s-primary-surface-light);--_color: var(--eui-c-s-primary-on-surface-light);--_close-hover-color: var(--eui-c-s-primary-surface-light-hover);--_border-outline-color: var(--eui-c-s-primary-border);--_border-color: var(--eui-c-s-primary-border-light)}.eui-19 :host.eui-chip--secondary{--_bg-color: var(--eui-c-s-secondary-surface-light);--_color: var(--eui-c-s-secondary-on-surface-light);--_close-hover-color: var(--eui-c-s-secondary-surface-light-hover);--_border-outline-color: var(--eui-c-s-secondary-border);--_border-color: var(--eui-c-s-secondary-border-light)}.eui-19 :host.eui-chip--info{--_bg-color: var(--eui-c-s-info-surface-light);--_color: var(--eui-c-s-info-on-surface-light);--_close-hover-color: var(--eui-c-s-info-surface-light-hover);--_border-outline-color: var(--eui-c-s-info-border);--_border-color: var(--eui-c-s-info-border-light)}.eui-19 :host.eui-chip--success{--_bg-color: var(--eui-c-s-success-surface-light);--_color: var(--eui-c-s-success-on-surface-light);--_close-hover-color: var(--eui-c-s-success-surface-light-hover);--_border-outline-color: var(--eui-c-s-success-border);--_border-color: var(--eui-c-s-success-border-light)}.eui-19 :host.eui-chip--warning{--_bg-color: var(--eui-c-s-warning-surface-light);--_color: var(--eui-c-s-warning-on-surface-light);--_close-hover-color: var(--eui-c-s-warning-surface-light-hover);--_border-outline-color: var(--eui-c-s-warning-border);--_border-color: var(--eui-c-s-warning-border-light)}.eui-19 :host.eui-chip--danger{--_bg-color: var(--eui-c-s-danger-surface-light);--_color: var(--eui-c-s-danger-on-surface-light);--_close-hover-color: var(--eui-c-s-danger-surface-light-hover);--_border-outline-color: var(--eui-c-s-danger-border);--_border-color: var(--eui-c-s-danger-border-light)}.eui-19 :host.eui-chip--accent{--_bg-color: var(--eui-c-s-accent-surface-light);--_color: var(--eui-c-s-accent-on-surface-light);--_close-hover-color: var(--eui-c-s-accent-surface-light-hover);--_border-outline-color: var(--eui-c-s-accent-border);--_border-color: var(--eui-c-s-accent-border-light)}.eui-19 :host.eui-chip--filled.eui-chip--primary{--_bg-color: var(--eui-c-s-primary-surface);--_color: var(--eui-c-s-primary-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-primary-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--secondary{--_bg-color: var(--eui-c-s-secondary-surface-medium);--_color: var(--eui-c-s-secondary-on-surface-medium);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-secondary-surface-medium-hover)}.eui-19 :host.eui-chip--filled.eui-chip--info{--_bg-color: var(--eui-c-s-info-surface);--_color: var(--eui-c-s-info-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-info-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--success{--_bg-color: var(--eui-c-s-success-surface);--_color: var(--eui-c-s-success-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-success-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--warning{--_bg-color: var(--eui-c-s-warning-surface);--_color: var(--eui-c-s-warning-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-warning-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--danger{--_bg-color: var(--eui-c-s-danger-surface);--_color: var(--eui-c-s-danger-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-danger-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--accent{--_bg-color: var(--eui-c-s-accent-surface);--_color: var(--eui-c-s-accent-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-accent-surface-hover)}.eui-19 :host.eui-chip{align-items:center;border-radius:calc(2 * var(--eui-br-xl));display:inline-flex;position:relative;font:var(--_size-m-font);min-height:calc(var(--eui-s-m) * 2);padding:0 var(--eui-s-s);outline:var(--eui-bw-xs) solid var(--_border-color);outline-offset:-1px;background-color:var(--_bg-color);color:var(--_color)}.eui-19 :host.eui-chip .eui-chip-wrapper,.eui-19 :host.eui-chip .eui-chip__content-container{display:flex;align-items:center;gap:var(--eui-s-xs)}.eui-19 :host.eui-chip ::ng-deep .eui-icon-svg:not(.eui-chip__close) svg{fill:var(--_color);color:var(--_color)}.eui-19 :host.eui-chip--outline{background-color:var(--eui-c-neutral-min);outline-color:var(--_border-outline-color)}.eui-19 :host.eui-chip--size-s{font:var(--_size-s-font);min-height:var(--eui-s-xl);padding:0 var(--eui-s-xs)}.eui-19 :host.eui-chip--size-s .eui-chip-wrapper,.eui-19 :host.eui-chip--size-s .eui-chip__content-container{gap:var(--eui-s-2xs)}.eui-19 :host.eui-chip--size-s .eui-chip-wrapper ::ng-deep svg,.eui-19 :host.eui-chip--size-s .eui-chip__content-container ::ng-deep svg{height:var(--eui-is-s);width:var(--eui-is-s)}.eui-19 :host.eui-chip--size-s .eui-chip-wrapper ::ng-deep .eui-flag-icon,.eui-19 :host.eui-chip--size-s .eui-chip__content-container ::ng-deep .eui-flag-icon{height:var(--eui-is-xs);min-width:calc(1.3333333 * var(--eui-is-xs));width:calc(1.3333333 * var(--eui-is-xs))}.eui-19 :host.eui-chip--size-s .eui-chip-wrapper ::ng-deep .eui-flag-icon.eui-flag-icon--rounded,.eui-19 :host.eui-chip--size-s .eui-chip__content-container ::ng-deep .eui-flag-icon.eui-flag-icon--rounded{height:var(--eui-is-s);width:var(--eui-is-s)}\n"], dependencies: [{ kind: "component", type: i2.EuiIconButtonComponent, selector: "eui-icon-button", inputs: ["icon", "iconUrl", "fillColor", "size", "ariaLabel", "tabindex", "hasNoPadding", "hasFocusHoverColor", "hasFocusHoverBg", "euiRounded", "euiDisabled"], outputs: ["buttonClick"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiChipComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-chip, span[euiChip], li[euiChip]', changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        ...EUI_ICON,
                        ...EUI_ICON_BUTTON,
                    ], hostDirectives: [
                        {
                            directive: BaseStatesDirective,
                            inputs: [
                                'euiPrimary',
                                'euiSecondary',
                                'euiSuccess',
                                'euiInfo',
                                'euiWarning',
                                'euiDanger',
                                'euiAccent',
                                'euiVariant',
                                'euiSizeS',
                                'euiOutline',
                                'euiDisabled',
                            ],
                        },
                    ], template: "<div class=\"eui-chip-wrapper\">\n    <div class=\"eui-chip__content-container\" #chipLabel>\n        <ng-content></ng-content>\n    </div>\n    @if (isChipRemovable) {\n        <eui-icon-button\n            class=\"eui-chip__close\"\n            ariaLabel=\"Remove {{ chipLabel.textContent }} chip\"\n            icon=\"close:outline\"\n            euiRounded\n            hasNoPadding\n            [euiVariant]=\"baseStatesDirective.euiVariant\"\n            (keydown.enter)=\"onRemove($event)\"\n            (keydown.backspace)=\"onRemove($event)\"\n            (buttonClick)=\"onRemove($event)\">\n        </eui-icon-button>\n    }\n</div>\n", styles: [".eui-19.eui-t-ds2025 :host.eui-chip{--_size-s-font: var(--eui-f-body-s-regular);--_size-m-font: var(--eui-f-body-m-regular)}.eui-19 :host.eui-chip{--_bg-color: var(--eui-c-s-secondary-surface-light);--_color: var(--eui-c-s-secondary-on-surface-light);--_close-hover-color: var(--eui-c-s-secondary-surface-light-hover);--_border-outline-color: var(--eui-c-s-secondary-border);--_border-color: var(--eui-c-s-secondary-border-light);--_size-s-font: var(--eui-f-s);--_size-m-font: var(--eui-f-m)}.eui-19 :host.eui-chip--primary{--_bg-color: var(--eui-c-s-primary-surface-light);--_color: var(--eui-c-s-primary-on-surface-light);--_close-hover-color: var(--eui-c-s-primary-surface-light-hover);--_border-outline-color: var(--eui-c-s-primary-border);--_border-color: var(--eui-c-s-primary-border-light)}.eui-19 :host.eui-chip--secondary{--_bg-color: var(--eui-c-s-secondary-surface-light);--_color: var(--eui-c-s-secondary-on-surface-light);--_close-hover-color: var(--eui-c-s-secondary-surface-light-hover);--_border-outline-color: var(--eui-c-s-secondary-border);--_border-color: var(--eui-c-s-secondary-border-light)}.eui-19 :host.eui-chip--info{--_bg-color: var(--eui-c-s-info-surface-light);--_color: var(--eui-c-s-info-on-surface-light);--_close-hover-color: var(--eui-c-s-info-surface-light-hover);--_border-outline-color: var(--eui-c-s-info-border);--_border-color: var(--eui-c-s-info-border-light)}.eui-19 :host.eui-chip--success{--_bg-color: var(--eui-c-s-success-surface-light);--_color: var(--eui-c-s-success-on-surface-light);--_close-hover-color: var(--eui-c-s-success-surface-light-hover);--_border-outline-color: var(--eui-c-s-success-border);--_border-color: var(--eui-c-s-success-border-light)}.eui-19 :host.eui-chip--warning{--_bg-color: var(--eui-c-s-warning-surface-light);--_color: var(--eui-c-s-warning-on-surface-light);--_close-hover-color: var(--eui-c-s-warning-surface-light-hover);--_border-outline-color: var(--eui-c-s-warning-border);--_border-color: var(--eui-c-s-warning-border-light)}.eui-19 :host.eui-chip--danger{--_bg-color: var(--eui-c-s-danger-surface-light);--_color: var(--eui-c-s-danger-on-surface-light);--_close-hover-color: var(--eui-c-s-danger-surface-light-hover);--_border-outline-color: var(--eui-c-s-danger-border);--_border-color: var(--eui-c-s-danger-border-light)}.eui-19 :host.eui-chip--accent{--_bg-color: var(--eui-c-s-accent-surface-light);--_color: var(--eui-c-s-accent-on-surface-light);--_close-hover-color: var(--eui-c-s-accent-surface-light-hover);--_border-outline-color: var(--eui-c-s-accent-border);--_border-color: var(--eui-c-s-accent-border-light)}.eui-19 :host.eui-chip--filled.eui-chip--primary{--_bg-color: var(--eui-c-s-primary-surface);--_color: var(--eui-c-s-primary-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-primary-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--secondary{--_bg-color: var(--eui-c-s-secondary-surface-medium);--_color: var(--eui-c-s-secondary-on-surface-medium);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-secondary-surface-medium-hover)}.eui-19 :host.eui-chip--filled.eui-chip--info{--_bg-color: var(--eui-c-s-info-surface);--_color: var(--eui-c-s-info-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-info-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--success{--_bg-color: var(--eui-c-s-success-surface);--_color: var(--eui-c-s-success-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-success-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--warning{--_bg-color: var(--eui-c-s-warning-surface);--_color: var(--eui-c-s-warning-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-warning-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--danger{--_bg-color: var(--eui-c-s-danger-surface);--_color: var(--eui-c-s-danger-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-danger-surface-hover)}.eui-19 :host.eui-chip--filled.eui-chip--accent{--_bg-color: var(--eui-c-s-accent-surface);--_color: var(--eui-c-s-accent-surface-contrast);--_border-color: transparent;--_close-hover-color: var(--eui-c-s-accent-surface-hover)}.eui-19 :host.eui-chip{align-items:center;border-radius:calc(2 * var(--eui-br-xl));display:inline-flex;position:relative;font:var(--_size-m-font);min-height:calc(var(--eui-s-m) * 2);padding:0 var(--eui-s-s);outline:var(--eui-bw-xs) solid var(--_border-color);outline-offset:-1px;background-color:var(--_bg-color);color:var(--_color)}.eui-19 :host.eui-chip .eui-chip-wrapper,.eui-19 :host.eui-chip .eui-chip__content-container{display:flex;align-items:center;gap:var(--eui-s-xs)}.eui-19 :host.eui-chip ::ng-deep .eui-icon-svg:not(.eui-chip__close) svg{fill:var(--_color);color:var(--_color)}.eui-19 :host.eui-chip--outline{background-color:var(--eui-c-neutral-min);outline-color:var(--_border-outline-color)}.eui-19 :host.eui-chip--size-s{font:var(--_size-s-font);min-height:var(--eui-s-xl);padding:0 var(--eui-s-xs)}.eui-19 :host.eui-chip--size-s .eui-chip-wrapper,.eui-19 :host.eui-chip--size-s .eui-chip__content-container{gap:var(--eui-s-2xs)}.eui-19 :host.eui-chip--size-s .eui-chip-wrapper ::ng-deep svg,.eui-19 :host.eui-chip--size-s .eui-chip__content-container ::ng-deep svg{height:var(--eui-is-s);width:var(--eui-is-s)}.eui-19 :host.eui-chip--size-s .eui-chip-wrapper ::ng-deep .eui-flag-icon,.eui-19 :host.eui-chip--size-s .eui-chip__content-container ::ng-deep .eui-flag-icon{height:var(--eui-is-xs);min-width:calc(1.3333333 * var(--eui-is-xs));width:calc(1.3333333 * var(--eui-is-xs))}.eui-19 :host.eui-chip--size-s .eui-chip-wrapper ::ng-deep .eui-flag-icon.eui-flag-icon--rounded,.eui-19 :host.eui-chip--size-s .eui-chip__content-container ::ng-deep .eui-flag-icon.eui-flag-icon--rounded{height:var(--eui-is-s);width:var(--eui-is-s)}\n"] }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }], ariaLabel: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-label']
            }], e2eAttr: [{
                type: HostBinding,
                args: ['attr.data-e2e']
            }, {
                type: Input
            }], euiInternalId: [{
                type: Input
            }], tooltipMessage: [{
                type: Input
            }], id: [{
                type: Input
            }], data: [{
                type: Input
            }], isChipRemovable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isSquared: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isFilled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], remove: [{
                type: Output
            }], euiIcons: [{
                type: ContentChildren,
                args: [forwardRef(() => EuiIconSvgComponent)]
            }], chipLabel: [{
                type: ViewChild,
                args: ['chipLabel']
            }] } });

class EuiChip {
    constructor(values = {}) {
        this.isRemovable = false;
        this.isOutline = false;
        this.isRounded = false;
        this.isDisabled = false;
        this.typeClass = 'primary';
        this.tooltip = new EuiChipTooltip();
        Object.assign(this, values);
    }
}
class EuiChipTooltip {
    constructor(values = {}) {
        this.position = 'above';
        this.contentAlignment = 'center';
        this.delay = 0;
        Object.assign(this, values);
    }
}

/**
 * @description
 * Module that provides the EuiChip component and its dependencies
 *
 * @deprecated Use {@link EUI_CHIP} instead.
 */
class EuiChipModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiChipModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiChipModule, imports: [EuiChipComponent], exports: [EuiChipComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiChipModule, imports: [EuiChipComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiChipModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiChipComponent],
                    exports: [EuiChipComponent],
                }]
        }] });

const EUI_CHIP = [
    EuiChipComponent,
];
// export { EuiChipComponent as EuiChipV2 } from './eui-chip.component';

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_CHIP, EuiChip, EuiChipComponent, EuiChipModule, EuiChipTooltip };
//# sourceMappingURL=eui-components-eui-chip.mjs.map
