import * as i0 from '@angular/core';
import { EventEmitter, inject, ElementRef, Renderer2, HostListener, HostBinding, Input, Output, Component, NgModule } from '@angular/core';
import { NgControl } from '@angular/forms';
import { InputDirective } from '@eui/components/shared';
import { coerceBooleanProperty } from '@angular/cdk/coercion';

/**
 * Angular component that provides a custom checkbox input implementation.
 * Extends {@link InputDirective} and implements form control functionality.
 *
 * @component
 * @selector input[euiInputCheckBox]
 * @implements {@link OnInit}
 * @implements {@link DoCheck}
 * @implements {@link OnChanges}
 * @implements {@link ControlValueAccessor}
 */
class EuiInputCheckboxComponent extends InputDirective {
    /**
     * Gets the CSS classes for the checkbox component.
     * Combines base classes with validation state classes.
     *
     * @returns {string} Space-separated list of CSS classes
     */
    get cssClasses() {
        return [this.getCssClasses('eui-input-checkbox'), this._isInvalid ? 'eui-input-checkbox--invalid' : ''].join(' ').trim();
    }
    /**
     * Controls the indeterminate (mixed) state of the checkbox.
     * When true, the checkbox appears in an indeterminate state.
     * This state is automatically cleared when the checkbox is clicked.
     *
     * @property {boolean} indeterminate
     */
    get indeterminate() {
        return this._indeterminate;
    }
    set indeterminate(value) {
        const changed = value != this._indeterminate;
        this._indeterminate = coerceBooleanProperty(value);
        if (changed) {
            this.indeterminateChange.emit(this._indeterminate);
        }
        this._syncIndeterminate(this._checked ? false : this._indeterminate);
    }
    /**
     * Controls the invalid state of the checkbox. Used for displaying validation errors.
     *
     * @property {boolean} isInvalid
     */
    get isInvalid() {
        return this._isInvalid || null;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    set isInvalid(state) {
        this.setInvalid(state);
    }
    /**
     * Controls the checked state of the checkbox.
     *
     * @property {boolean} checked
     */
    get checked() {
        return this._checked;
    }
    set checked(value) {
        this._checked = coerceBooleanProperty(value) ? true : undefined;
    }
    constructor() {
        super();
        /**
         * Event emitter that fires when the indeterminate state changes.
         *
         * @event indeterminateChange
         * @type {EventEmitter<boolean>}
         */
        this.indeterminateChange = new EventEmitter();
        this.type = 'checkbox';
        this.ngControl = inject(NgControl, { optional: true, self: true });
        this._elementRef = inject(ElementRef);
        this._renderer = inject(Renderer2);
        this._indeterminate = false;
        this.onChange = (_) => {
            /* Nothing to be Done so far */
        };
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.onBlur = (_) => {
            /* Nothing to be Done so far */
        };
        // if there's no id attribute set one
        if (!this._elementRef.nativeElement.id) {
            this.setIdAttribute();
        }
        // register control valueAccessor
        if (this.ngControl) {
            this.ngControl.valueAccessor = this;
        }
    }
    /**
     * Lifecycle hook that is called after data-bound properties are initialized.
     * Sets the default control value if needed.
     */
    ngOnInit() {
        super.ngOnInit();
        // in case control value is null set the default one (isChecked) and sync Control State
        if (this.ngControl?.control?.value === null) {
            this.ngControl.control.setValue(this._checked, { emitModelToViewChange: false });
            // changing Model Expression after view checked, so detect changes
            // TODO: check why although it's checked .checked returns false
            // this.ngControl.viewToModelUpdate(this._checked);
            // this._cd.detectChanges();
        }
    }
    /**
     * Lifecycle hook that performs custom change detection.
     * Updates invalid state based on control status.
     */
    ngDoCheck() {
        if (this.ngControl) {
            this._isInvalid = this.ngControl.invalid && this.ngControl.touched;
        }
    }
    /**
     * Lifecycle hook that is called when data-bound properties change.
     * Handles changes to checked and readonly states.
     *
     * @param {SimpleChanges} changes - Object containing changed properties
     */
    ngOnChanges(changes) {
        if (changes['checked']) {
            const currentValue = coerceBooleanProperty(changes['checked']?.currentValue);
            if (currentValue !== this?.ngControl?.control?.value) {
                this._checked = currentValue;
                this._elementRef.nativeElement.checked = currentValue;
            }
        }
        if (changes['readonly']) {
            const readonly = coerceBooleanProperty(changes['readonly']?.currentValue);
            if (readonly) {
                this._renderer.setAttribute(this._elementRef.nativeElement, 'readonly', null);
            }
            else {
                this._renderer.removeAttribute(this._elementRef.nativeElement, 'readonly');
            }
        }
    }
    /**
     * Implements ControlValueAccessor writeValue method.
     * Updates the checked state of the checkbox.
     *
     * @param {boolean} obj - The value to write
     */
    writeValue(obj) {
        this._checked = coerceBooleanProperty(obj) ? true : undefined;
        this._elementRef.nativeElement.checked = this._checked ? true : undefined;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnChange(fn) {
        this.onChange = fn;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnTouched(fn) {
        this.onBlur = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    /**
     * Event handler for checkbox change events.
     *
     * @param {boolean} checked - The new checked state
     * @protected
     */
    onChanged(checked) {
        this.onChange(checked);
    }
    /**
     * Event handler for space key press.
     * Prevents space key action when checkbox is readonly.
     *
     * @param {KeyboardEvent} event - The keyboard event
     * @protected
     */
    onSpacePressed(event) {
        if (this.readonly) {
            event.preventDefault();
            event.stopPropagation();
        }
    }
    /**
     * Sets the invalid state of the checkbox.
     *
     * @deprecated Use the boolean version instead
     * @param state - The invalid state to set (true/false)
     * @protected
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setInvalid(state) {
        // in case it's controlled by NgControl override
        this._isInvalid = this.control ? this.control.invalid && this.control.touched : coerceBooleanProperty(state);
    }
    /**
     * Sets the indeterminate state of the checkbox. This is also known as "mixed" mode and can be used to
     * represent a checkbox with three states, e.g. a checkbox that represents a nested list of
     * check-able items.
     *
     * @param value
     */
    _syncIndeterminate(value) {
        if (this._elementRef) {
            this._elementRef.nativeElement.indeterminate = value;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputCheckboxComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.12", type: EuiInputCheckboxComponent, isStandalone: true, selector: "input[euiInputCheckBox]", inputs: { indeterminate: "indeterminate", isInvalid: "isInvalid", checked: "checked" }, outputs: { indeterminateChange: "indeterminateChange" }, host: { listeners: { "change": "onChanged($event.target.checked)", "keydown.space": "onSpacePressed($event)" }, properties: { "class": "this.cssClasses", "attr.type": "this.type", "attr.checked": "this.checked" } }, usesInheritance: true, usesOnChanges: true, ngImport: i0, template: '', isInline: true, styles: [".eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden){appearance:inherit;align-items:center;cursor:pointer;display:inline-flex;flex-direction:row;flex-shrink:0;height:var(--eui-s-xl);margin-right:var(--eui-s-s);position:relative;vertical-align:middle;width:var(--eui-s-xl);accent-color:var(--eui-c-white);background:var(--eui-c-white);border:var(--eui-bw-s) solid var(--eui-c-neutral-light)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)+::ng-deep .eui-label,.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)+::ng-deep label{display:inline-flex;cursor:pointer;margin-right:var(--eui-s-m);white-space:inherit}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):checked{background:var(--eui-c-s-primary-surface)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):checked:before{height:1rem;width:1rem;content:\"\";mask-repeat:no-repeat;mask-position:50% 50%;mask-size:cover;mask-image:var(--eui-internal-icon-checkmark-path);background-color:var(--eui-c-white);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):indeterminate{background:var(--eui-c-s-primary-surface)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):indeterminate:before{height:1rem;width:1rem;content:\"\";mask-repeat:no-repeat;mask-position:50% 50%;mask-size:cover;mask-image:var(--eui-internal-icon-remove-path);background-color:var(--eui-c-white);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):disabled:not([readonly]){background:var(--eui-c-neutral-lightest);border:var(--eui-bw-s) solid var(--eui-c-neutral-light);opacity:.35;pointer-events:none;-webkit-user-select:none;user-select:none}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):disabled:not([readonly]):checked:before{height:1rem;width:1rem;content:var(--eui-internal-icon-checkmark-path);background-color:var(--eui-c-neutral);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):disabled:not([readonly])+::ng-deep label{pointer-events:none}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)[readonly]{opacity:.5;pointer-events:none;-webkit-user-select:none;user-select:none}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)[readonly]:checked{background:var(--eui-c-s-primary-surface);border:var(--eui-bw-s) solid var(--eui-c-s-primary-base)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)[readonly]:checked:before{height:1rem;width:1rem;content:\"\";mask-repeat:no-repeat;mask-position:50% 50%;mask-size:cover;mask-image:var(--eui-internal-icon-checkmark-path);background-color:var(--eui-c-white);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)[readonly]+::ng-deep label{align-items:center;pointer-events:none}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--invalid:not(:disabled):not([readonly]),.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--danger:not(:disabled):not([readonly]){accent-color:var(--eui-c-s-danger-surface);appearance:inherit;background-color:var(--eui-c-white);border:var(--eui-bw-s) solid var(--eui-c-s-danger-base)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--invalid:not(:disabled):not([readonly]):checked,.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--danger:not(:disabled):not([readonly]):checked{background:var(--eui-c-s-danger-surface)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--invalid:not(:disabled):not([readonly]):checked:before,.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--danger:not(:disabled):not([readonly]):checked:before{height:1rem;width:1rem;content:\"\";mask-repeat:no-repeat;mask-position:50% 50%;mask-size:cover;mask-image:var(--eui-internal-icon-checkmark-path);background-color:var(--eui-c-white);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):focus:not([readonly]){outline:var(--eui-bw-s) solid var(--eui-c-primary-lighter)!important;outline-offset:1px!important;border-radius:var(--eui-br-s)!important}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--invalid:not([readonly]),.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--danger:not([readonly]){outline-color:var(--eui-c-danger-lighter)!important}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputCheckboxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'input[euiInputCheckBox]', template: '', styles: [".eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden){appearance:inherit;align-items:center;cursor:pointer;display:inline-flex;flex-direction:row;flex-shrink:0;height:var(--eui-s-xl);margin-right:var(--eui-s-s);position:relative;vertical-align:middle;width:var(--eui-s-xl);accent-color:var(--eui-c-white);background:var(--eui-c-white);border:var(--eui-bw-s) solid var(--eui-c-neutral-light)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)+::ng-deep .eui-label,.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)+::ng-deep label{display:inline-flex;cursor:pointer;margin-right:var(--eui-s-m);white-space:inherit}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):checked{background:var(--eui-c-s-primary-surface)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):checked:before{height:1rem;width:1rem;content:\"\";mask-repeat:no-repeat;mask-position:50% 50%;mask-size:cover;mask-image:var(--eui-internal-icon-checkmark-path);background-color:var(--eui-c-white);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):indeterminate{background:var(--eui-c-s-primary-surface)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):indeterminate:before{height:1rem;width:1rem;content:\"\";mask-repeat:no-repeat;mask-position:50% 50%;mask-size:cover;mask-image:var(--eui-internal-icon-remove-path);background-color:var(--eui-c-white);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):disabled:not([readonly]){background:var(--eui-c-neutral-lightest);border:var(--eui-bw-s) solid var(--eui-c-neutral-light);opacity:.35;pointer-events:none;-webkit-user-select:none;user-select:none}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):disabled:not([readonly]):checked:before{height:1rem;width:1rem;content:var(--eui-internal-icon-checkmark-path);background-color:var(--eui-c-neutral);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):disabled:not([readonly])+::ng-deep label{pointer-events:none}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)[readonly]{opacity:.5;pointer-events:none;-webkit-user-select:none;user-select:none}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)[readonly]:checked{background:var(--eui-c-s-primary-surface);border:var(--eui-bw-s) solid var(--eui-c-s-primary-base)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)[readonly]:checked:before{height:1rem;width:1rem;content:\"\";mask-repeat:no-repeat;mask-position:50% 50%;mask-size:cover;mask-image:var(--eui-internal-icon-checkmark-path);background-color:var(--eui-c-white);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden)[readonly]+::ng-deep label{align-items:center;pointer-events:none}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--invalid:not(:disabled):not([readonly]),.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--danger:not(:disabled):not([readonly]){accent-color:var(--eui-c-s-danger-surface);appearance:inherit;background-color:var(--eui-c-white);border:var(--eui-bw-s) solid var(--eui-c-s-danger-base)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--invalid:not(:disabled):not([readonly]):checked,.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--danger:not(:disabled):not([readonly]):checked{background:var(--eui-c-s-danger-surface)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--invalid:not(:disabled):not([readonly]):checked:before,.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--danger:not(:disabled):not([readonly]):checked:before{height:1rem;width:1rem;content:\"\";mask-repeat:no-repeat;mask-position:50% 50%;mask-size:cover;mask-image:var(--eui-internal-icon-checkmark-path);background-color:var(--eui-c-white);height:var(--eui-s-xl);width:var(--eui-s-xl)}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden):focus:not([readonly]){outline:var(--eui-bw-s) solid var(--eui-c-primary-lighter)!important;outline-offset:1px!important;border-radius:var(--eui-br-s)!important}.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--invalid:not([readonly]),.eui-19 :host.eui-input-checkbox:not(.cdk-visually-hidden).eui-input-checkbox--danger:not([readonly]){outline-color:var(--eui-c-danger-lighter)!important}\n"] }]
        }], ctorParameters: () => [], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], indeterminateChange: [{
                type: Output
            }], indeterminate: [{
                type: Input
            }], isInvalid: [{
                type: Input
            }], type: [{
                type: HostBinding,
                args: ['attr.type']
            }], checked: [{
                type: HostBinding,
                args: ['attr.checked']
            }, {
                type: Input
            }], onChanged: [{
                type: HostListener,
                args: ['change', ['$event.target.checked']]
            }], onSpacePressed: [{
                type: HostListener,
                args: ['keydown.space', ['$event']]
            }] } });

/**
 * Angular module for the EUI Input Checkbox component. Provides the checkbox
 * component and its dependencies.
 *
 * @deprecated Use {@link `EUI_INPUT_CHECKBOX`} instead.
 */
class EuiInputCheckboxModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputCheckboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiInputCheckboxModule, imports: [EuiInputCheckboxComponent], exports: [EuiInputCheckboxComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputCheckboxModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputCheckboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiInputCheckboxComponent],
                    exports: [EuiInputCheckboxComponent],
                }]
        }] });

const EUI_INPUT_CHECKBOX = [
    EuiInputCheckboxComponent,
];
// export { EuiInputCheckboxComponent as EuiInputCheckbox } from './eui-input-checkbox.component';

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_INPUT_CHECKBOX, EuiInputCheckboxComponent, EuiInputCheckboxModule };
//# sourceMappingURL=eui-components-eui-input-checkbox.mjs.map
