import * as i0 from '@angular/core';
import { inject, ElementRef, Renderer2, Input, HostBinding, Component, NgModule } from '@angular/core';
import { NgControl } from '@angular/forms';
import { InputDirective } from '@eui/components/shared';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import * as i1 from '@eui/components/directives';
import { EuiClearableDirective, EuiLoadingDirective } from '@eui/components/directives';

/**
 * @description
 * A custom input text component that extends InputDirective and provides additional functionality
 * such as validation states, clearable input, and loading states.
 */
class EuiInputTextComponent extends InputDirective {
    constructor() {
        super(...arguments);
        this.control = inject(NgControl, { optional: true, self: true });
        this._elementRef = inject(ElementRef);
        this._renderer = inject(Renderer2);
    }
    /**
     * @description
     * Gets the CSS classes for the component, including validation state classes
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get class() {
        return [super.getCssClasses('eui-input-text'), this._isInvalid ? 'eui-input-text--invalid' : ''].join(' ').trim();
    }
    /**
     * @description
     * Gets or sets the invalid state of the input
     * When used with NgControl, this state is automatically managed based on control state
     *
     * @returns {boolean} Current invalid state
     */
    get isInvalid() {
        return this._isInvalid || null;
    }
    /**
     * @param {BooleanInput} state - The invalid state to set
     */
    set isInvalid(state) {
        this.setInvalid(state);
    }
    /**
     * @description
     * Initializes the component and sets the root class name
     */
    ngOnInit() {
        super.ngOnInit();
        this._renderer.setProperty(this._elementRef.nativeElement, 'rootClassName', 'eui-input-text');
    }
    /**
     * @description
     * Cleans up component resources
     */
    ngOnDestroy() {
        super.ngOnDestroy();
    }
    /**
     * @description
     * Checks and updates the invalid state when using NgControl
     */
    ngDoCheck() {
        if (this.control) {
            this.isInvalid = this.control.invalid && this.control.touched;
        }
    }
    /**
     * @description
     * Sets the invalid state of the input and updates related properties
     *
     * @param {BooleanInput} state - The invalid state to set
     * @protected
     */
    setInvalid(state) {
        // in case it's controlled by NgControl override
        this._isInvalid = this.control ? this.control.invalid && this.control.touched : coerceBooleanProperty(state);
        // set BaseDirective Attribute
        this.euiDanger = this._isInvalid;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputTextComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.12", type: EuiInputTextComponent, isStandalone: true, selector: "input[euiInputText]", inputs: { isInvalid: "isInvalid" }, host: { properties: { "class": "this.class" } }, usesInheritance: true, hostDirectives: [{ directive: i1.EuiClearableDirective, inputs: ["euiClearable", "euiClearable", "readonly", "readonly", "disabled", "disabled"] }, { directive: i1.EuiLoadingDirective, inputs: ["euiLoading", "euiLoading", "readonly", "readonly"] }], ngImport: i0, template: '', isInline: true, styles: [".eui-19 :host.eui-input-text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;font:var(--eui-f-m);appearance:none;background-color:var(--eui-c-white);border:1px solid var(--eui-c-neutral-lighter);border-radius:var(--eui-br-m);box-shadow:none;color:var(--eui-c-text);padding:calc(var(--eui-s-xs) - 1px) calc(var(--eui-s-m) - 1px);width:100%}.eui-19 :host.eui-input-text:focus:not([readonly]){outline:2px solid var(--eui-c-focus)!important;outline-offset:-2px!important;transition:none}.eui-19 :host.eui-input-text:focus-visible:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 :host.eui-input-text [tabindex=\"0\"]:focus:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 :host.eui-input-text:not([hidden]){display:block}.eui-19 :host.eui-input-text::placeholder{color:var(--eui-c-neutral-lighter)!important;opacity:1}.eui-19 :host.eui-input-text[readonly]{background-color:transparent;border-color:transparent;box-shadow:none;height:inherit;padding-left:0;padding-right:0;pointer-events:none}.eui-19 :host.eui-input-text[readonly]+.eui-feedback-message,.eui-19 :host.eui-input-text[readonly]+.eui-input-maxlength{appearance:none;display:none}.eui-19 :host.eui-input-text[disabled]:not([readonly]),.eui-19 :host.eui-input-text--disabled:not([readonly]){background-color:var(--eui-c-neutral-bg-light)!important;border:1px solid var(--eui-c-neutral-lightest);color:var(--eui-c-neutral-light);pointer-events:none}.eui-19 :host.eui-input-text--invalid,.eui-19 :host.eui-input-text--danger{border:1px solid var(--eui-c-danger)}.eui-19 :host.eui-input-text--loading{padding-right:var(--eui-s-2xl)}.eui-19 :host.eui-input-text--loading-icon{align-items:center;display:flex}.eui-19 :host.eui-input-text--loading-icon:after,.eui-19 :host.eui-input-text--loading-icon:before{content:\"\";height:var(--eui-s-l);position:absolute;right:var(--eui-s-s);width:var(--eui-s-l)}.eui-19 :host.eui-input-text--loading-icon:before{border:var(--eui-s-2xs) solid rgba(0,0,0,.35);border-radius:100%}.eui-19 :host.eui-input-text--loading-icon:after{animation:loading .6s linear;animation-iteration-count:infinite;border-color:var(--eui-c-white) transparent transparent;border-radius:100%;border-style:solid;border-width:var(--eui-s-2xs);box-shadow:0 0 0 1px transparent}.eui-19 :host.eui-input-text--loading-icon--sm:after,.eui-19 :host.eui-input-text--loading-icon--sm:before{height:var(--eui-s-m);width:var(--eui-s-m)}@keyframes loading{to{transform:rotate(360deg)}}.eui-19 :host.eui-input-text[readonly]{pointer-events:auto}.eui-19 :host.eui-input-text[type=search]::-webkit-search-cancel-button{display:none}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputTextComponent, decorators: [{
            type: Component,
            args: [{ selector: 'input[euiInputText]', template: '', hostDirectives: [
                        {
                            directive: EuiClearableDirective,
                            inputs: ['euiClearable', 'readonly', 'disabled'],
                        },
                        {
                            directive: EuiLoadingDirective,
                            inputs: ['euiLoading', 'readonly'],
                        },
                    ], styles: [".eui-19 :host.eui-input-text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;font:var(--eui-f-m);appearance:none;background-color:var(--eui-c-white);border:1px solid var(--eui-c-neutral-lighter);border-radius:var(--eui-br-m);box-shadow:none;color:var(--eui-c-text);padding:calc(var(--eui-s-xs) - 1px) calc(var(--eui-s-m) - 1px);width:100%}.eui-19 :host.eui-input-text:focus:not([readonly]){outline:2px solid var(--eui-c-focus)!important;outline-offset:-2px!important;transition:none}.eui-19 :host.eui-input-text:focus-visible:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 :host.eui-input-text [tabindex=\"0\"]:focus:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 :host.eui-input-text:not([hidden]){display:block}.eui-19 :host.eui-input-text::placeholder{color:var(--eui-c-neutral-lighter)!important;opacity:1}.eui-19 :host.eui-input-text[readonly]{background-color:transparent;border-color:transparent;box-shadow:none;height:inherit;padding-left:0;padding-right:0;pointer-events:none}.eui-19 :host.eui-input-text[readonly]+.eui-feedback-message,.eui-19 :host.eui-input-text[readonly]+.eui-input-maxlength{appearance:none;display:none}.eui-19 :host.eui-input-text[disabled]:not([readonly]),.eui-19 :host.eui-input-text--disabled:not([readonly]){background-color:var(--eui-c-neutral-bg-light)!important;border:1px solid var(--eui-c-neutral-lightest);color:var(--eui-c-neutral-light);pointer-events:none}.eui-19 :host.eui-input-text--invalid,.eui-19 :host.eui-input-text--danger{border:1px solid var(--eui-c-danger)}.eui-19 :host.eui-input-text--loading{padding-right:var(--eui-s-2xl)}.eui-19 :host.eui-input-text--loading-icon{align-items:center;display:flex}.eui-19 :host.eui-input-text--loading-icon:after,.eui-19 :host.eui-input-text--loading-icon:before{content:\"\";height:var(--eui-s-l);position:absolute;right:var(--eui-s-s);width:var(--eui-s-l)}.eui-19 :host.eui-input-text--loading-icon:before{border:var(--eui-s-2xs) solid rgba(0,0,0,.35);border-radius:100%}.eui-19 :host.eui-input-text--loading-icon:after{animation:loading .6s linear;animation-iteration-count:infinite;border-color:var(--eui-c-white) transparent transparent;border-radius:100%;border-style:solid;border-width:var(--eui-s-2xs);box-shadow:0 0 0 1px transparent}.eui-19 :host.eui-input-text--loading-icon--sm:after,.eui-19 :host.eui-input-text--loading-icon--sm:before{height:var(--eui-s-m);width:var(--eui-s-m)}@keyframes loading{to{transform:rotate(360deg)}}.eui-19 :host.eui-input-text[readonly]{pointer-events:auto}.eui-19 :host.eui-input-text[type=search]::-webkit-search-cancel-button{display:none}\n"] }]
        }], propDecorators: { class: [{
                type: HostBinding,
                args: ['class']
            }], isInvalid: [{
                type: Input
            }] } });

/**
 * @description
 * Module that provides the EuiInputText component and its dependencies
 *
 * @deprecated
 * Use {@link `EuiInputTextComponent`} instead. This module is deprecated and
 * will be removed in the next major version of the library.
 */
class EuiInputTextModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputTextModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiInputTextModule, imports: [EuiInputTextComponent], exports: [EuiInputTextComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputTextModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiInputTextModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiInputTextComponent],
                    exports: [EuiInputTextComponent],
                }]
        }] });

const EUI_INPUT_TEXT = [
    EuiInputTextComponent,
];
// export { EuiInputTextComponent as EuiInputText } from './eui-input-text.component';

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_INPUT_TEXT, EuiInputTextComponent, EuiInputTextModule };
//# sourceMappingURL=eui-components-eui-input-text.mjs.map
