import * as i0 from '@angular/core';
import { EventEmitter, inject, ChangeDetectorRef, forwardRef, numberAttribute, booleanAttribute, HostListener, HostBinding, Output, Input, ChangeDetectionStrategy, Component } from '@angular/core';
import { ReactiveFormsModule, NG_VALUE_ACCESSOR } from '@angular/forms';
import * as i1 from '@eui/components/shared';
import { BaseStatesDirective } from '@eui/components/shared';
import * as i2 from '@eui/components/eui-icon';
import { EUI_ICON } from '@eui/components/eui-icon';
import * as i3 from '@eui/components/eui-button';
import { EUI_BUTTON } from '@eui/components/eui-button';

/**
 * @description
 * Rating component that can be used as a standalone start rating or within reactive forms.
 *
 * @implements {ControlValueAccessor}
 */
class EuiRatingComponent {
    constructor() {
        /**
         * Unique identifier for the toggle
         * @default Generated unique ID with 'eui-rating-' prefix
        */
        // @Input() id = `eui-rating-${uniqueId()}`;
        /**
         * Whether the toggle is disabled
         * @default false
        */
        this.euiDisabled = false;
        /**
         * Current numbers of stars rating to display
         * @default 5
        */
        this.numberOfStars = 5;
        /**
         * Current rating number
         * @default 0
        */
        this.rating = 0;
        /**
         * Event emitted when toggle state changes
         * @emits boolean - The new toggle state
        */
        this.ratingChange = new EventEmitter();
        /**
         * Binds the tabindex attribute to the component.
        *
        * @default 0
        */
        this.tabindex = 0;
        // eslint-disable-next-line
        this.numbers = [];
        this.baseStatesDirective = inject(BaseStatesDirective);
        this.cd = inject(ChangeDetectorRef);
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.onChange = () => { };
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.onTouch = () => { };
    }
    /** CSS classes applied to the host element */
    get cssClasses() {
        return [this.baseStatesDirective.getCssClasses('eui-rating')].join(' ').trim();
    }
    onKeydown(event) {
        switch (event.key) {
            case 'Delete': {
                this.updateRating(0);
                break;
            }
            case 'ArrowRight': {
                if (this.rating < this.numberOfStars) {
                    this.updateRating(this.rating + 1, false);
                }
                break;
            }
            case 'ArrowLeft': {
                if (this.rating > 0) {
                    this.updateRating(this.rating - 1, false);
                }
                break;
            }
        }
    }
    ngOnInit() {
        this.initState();
    }
    /**
     * Implements ControlValueAccessor
     * Updates the toggle's checked state
    */
    writeValue(value) {
        this.rating = value;
        this.updateState();
        this.cd.detectChanges();
    }
    /**
     * Implements ControlValueAccessor
     * Updates the rating's disabled state
    */
    setDisabledState(isDisabled) {
        this.euiDisabled = isDisabled;
        this.cd.detectChanges();
    }
    /**
     * Handles focus out event
     * Notifies form control of touch event
    */
    onFocusOut() {
        this.onTouch();
    }
    /**
     * Implements ControlValueAccessor
     * Registers change handler
     * @todo Improve type definition or make generic
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * Implements ControlValueAccessor
     * Registers touch handler
     * @todo Improve type definition or make generic
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnTouched(fn) {
        this.onTouch = fn;
    }
    /**
     * Toggles the current state if not disabled
     * Emits the new state and notifies form control
     */
    onUpdate(rating) {
        this.updateRating(rating, true);
    }
    initState() {
        for (let i = 1; i < this.numberOfStars + 1; i++) {
            this.numbers.push({
                index: i,
                value: i <= this.rating,
            });
        }
    }
    updateState() {
        for (let i = 1; i < this.numberOfStars + 1; i++) {
            this.numbers[i - 1].value = i <= this.rating;
        }
    }
    updateRating(rating, clearifSame = false) {
        if (!this.euiDisabled) {
            if (this.rating === rating && clearifSame) {
                this.rating = 0;
            }
            else {
                this.rating = rating;
            }
            this.updateState();
            this.onChange(this.rating);
            this.ratingChange.next(this.rating);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiRatingComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiRatingComponent, isStandalone: true, selector: "eui-rating", inputs: { euiDisabled: ["euiDisabled", "euiDisabled", booleanAttribute], numberOfStars: ["numberOfStars", "numberOfStars", numberAttribute], rating: ["rating", "rating", numberAttribute] }, outputs: { ratingChange: "ratingChange" }, host: { listeners: { "keydown": "onKeydown($event)" }, properties: { "class": "this.cssClasses", "attr.tabindex": "this.tabindex" } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => EuiRatingComponent),
                multi: true,
            },
        ], hostDirectives: [{ directive: i1.BaseStatesDirective }], ngImport: i0, template: "@for (n of numbers; track n.index) {\n    <button euiButton euiPrimary euiRounded euiBasicButton euiIconButton euiSizeS hasNoFocusRing isCompact [euiDisabled]=\"euiDisabled\" (click)=\"onUpdate(n.index)\" [attr.tabindex]=\"-1\">\n        @if (n.value) {\n            <eui-icon-svg icon=\"star:phosphor-fill\" fillColor=\"accent\"/>\n        } @else {\n            <eui-icon-svg icon=\"star:phosphor-light\" fillColor=\"primary\"/>\n        }\n    </button>\n}\n", styles: [".eui-19 :host.eui-rating{display:inline-flex}.eui-19 :host.eui-rating:focus-visible:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}\n"], dependencies: [{ kind: "ngmodule", type: ReactiveFormsModule }, { kind: "component", type: i2.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i3.EuiButtonComponent, selector: "button[euiButton], a[euiButton]", inputs: ["e2eAttr", "id", "euiBasicButton", "euiButtonCall", "euiCTAButton", "euiBlockButton", "euiIconButton", "euiAvatarButton", "euiLineWrap", "isCompact", "hasNoFocusRing", "isChecked", "euiDisabled"], outputs: ["buttonClick"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiRatingComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-rating', changeDetection: ChangeDetectionStrategy.OnPush, hostDirectives: [
                        {
                            directive: BaseStatesDirective,
                        },
                    ], imports: [
                        ReactiveFormsModule,
                        ...EUI_ICON,
                        ...EUI_BUTTON,
                    ], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => EuiRatingComponent),
                            multi: true,
                        },
                    ], template: "@for (n of numbers; track n.index) {\n    <button euiButton euiPrimary euiRounded euiBasicButton euiIconButton euiSizeS hasNoFocusRing isCompact [euiDisabled]=\"euiDisabled\" (click)=\"onUpdate(n.index)\" [attr.tabindex]=\"-1\">\n        @if (n.value) {\n            <eui-icon-svg icon=\"star:phosphor-fill\" fillColor=\"accent\"/>\n        } @else {\n            <eui-icon-svg icon=\"star:phosphor-light\" fillColor=\"primary\"/>\n        }\n    </button>\n}\n", styles: [".eui-19 :host.eui-rating{display:inline-flex}.eui-19 :host.eui-rating:focus-visible:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}\n"] }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], euiDisabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], numberOfStars: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], rating: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], ratingChange: [{
                type: Output
            }], tabindex: [{
                type: HostBinding,
                args: ['attr.tabindex']
            }], onKeydown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

const EUI_RATING = [
    EuiRatingComponent,
];
// export { EuiRatingComponent as EuiRating } from './eui-rating.component';

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_RATING, EuiRatingComponent };
//# sourceMappingURL=eui-components-eui-rating.mjs.map
